@@ -7,16 +7,19 @@ import (
 	"errors"
 	"net"
 	"os"
+	"os/signal"
+	"syscall"
 	"time"
 
 	"github.com/mdlayher/vsock"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 
-	"github.com/lima-vm/lima/pkg/guestagent"
-	"github.com/lima-vm/lima/pkg/guestagent/api/server"
-	"github.com/lima-vm/lima/pkg/guestagent/serialport"
-	"github.com/lima-vm/lima/pkg/portfwdserver"
+	"github.com/lima-vm/lima/v2/pkg/guestagent"
+	"github.com/lima-vm/lima/v2/pkg/guestagent/api/server"
+	"github.com/lima-vm/lima/v2/pkg/guestagent/serialport"
+	"github.com/lima-vm/lima/v2/pkg/guestagent/ticker"
+	"github.com/lima-vm/lima/v2/pkg/portfwdserver"
 )
 
 func newDaemonCommand() *cobra.Command {
@@ -25,6 +28,7 @@ func newDaemonCommand() *cobra.Command {
 		Short: "Run the daemon",
 		RunE:  daemonAction,
 	}
+	daemonCommand.Flags().String("runtime-dir", "/run/lima-guestagent", "Directory to store runtime state")
 	daemonCommand.Flags().Duration("tick", 3*time.Second, "Tick for polling events")
 	daemonCommand.Flags().Int("vsock-port", 0, "Use vsock server instead a UNIX socket")
 	daemonCommand.Flags().String("virtio-port", "", "Use virtio server instead a UNIX socket")
@@ -32,6 +36,14 @@ func newDaemonCommand() *cobra.Command {
 }
 
 func daemonAction(cmd *cobra.Command, _ []string) error {
+	ctx := cmd.Context()
+	runtimeDir, err := cmd.Flags().GetString("runtime-dir")
+	if err != nil {
+		return err
+	}
+	if err := os.MkdirAll(runtimeDir, 0o755); err != nil {
+		return err
+	}
 	socket := "/run/lima-guestagent.sock"
 	tick, err := cmd.Flags().GetDuration("tick")
 	if err != nil {
@@ -51,20 +63,30 @@ func daemonAction(cmd *cobra.Command, _ []string) error {
 	if os.Geteuid() != 0 {
 		return errors.New("must run as the root user")
 	}
-	logrus.Infof("event tick: %v", tick)
 
-	newTicker := func() (<-chan time.Time, func()) {
-		// TODO: use an equivalent of `bpftrace -e 'tracepoint:syscalls:sys_*_bind { printf("tick\n"); }')`,
-		// without depending on `bpftrace` binary.
-		// The agent binary will need CAP_BPF file cap.
-		ticker := time.NewTicker(tick)
-		return ticker.C, ticker.Stop
+	logrus.Infof("event tick: %v", tick)
+	simpleTicker := ticker.NewSimpleTicker(time.NewTicker(tick))
+	tickerInst := simpleTicker
+	// See /sys/kernel/debug/tracing/available_events for the list of available tracepoints
+	tracepoints := []string{"syscalls:sys_exit_bind"}
+	if ebpfTicker, err := ticker.NewEbpfTicker(tracepoints); err != nil {
+		logrus.WithError(err).Warn("failed to create eBPF ticker, falling back to simple ticker")
+	} else {
+		logrus.Infof("using eBPF ticker with tracepoints: %v", tracepoints)
+		tickerInst = ticker.NewCompoundTicker(simpleTicker, ebpfTicker)
 	}
 
-	agent, err := guestagent.New(newTicker, tick*20)
+	ctx, stop := signal.NotifyContext(ctx, syscall.SIGTERM)
+	defer stop()
+	go func() {
+		<-ctx.Done()
+		logrus.Debug("Received SIGTERM, shutting down the guest agent")
+	}()
+	agent, err := guestagent.New(ctx, tickerInst, runtimeDir)
 	if err != nil {
 		return err
 	}
+
 	err = os.RemoveAll(socket)
 	if err != nil {
 		return err
@@ -86,7 +108,8 @@ func daemonAction(cmd *cobra.Command, _ []string) error {
 		l = vsockL
 		logrus.Infof("serving the guest agent on vsock port: %d", vSockPort)
 	} else {
-		socketL, err := net.Listen("unix", socket)
+		var lc net.ListenConfig
+		socketL, err := lc.Listen(ctx, "unix", socket)
 		if err != nil {
 			return err
 		}
@@ -96,5 +119,6 @@ func daemonAction(cmd *cobra.Command, _ []string) error {
 		l = socketL
 		logrus.Infof("serving the guest agent on %q", socket)
 	}
-	return server.StartServer(l, &server.GuestServer{Agent: agent, TunnelS: portfwdserver.NewTunnelServer()})
+	defer logrus.Debug("exiting lima-guestagent daemon")
+	return server.StartServer(ctx, l, &server.GuestServer{Agent: agent, TunnelS: portfwdserver.NewTunnelServer()})
 }
