@@ -13,15 +13,19 @@ import (
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 
-	"github.com/lima-vm/lima/cmd/limactl/editflags"
-	"github.com/lima-vm/lima/pkg/editutil"
-	"github.com/lima-vm/lima/pkg/instance"
-	"github.com/lima-vm/lima/pkg/limayaml"
-	networks "github.com/lima-vm/lima/pkg/networks/reconcile"
-	"github.com/lima-vm/lima/pkg/store"
-	"github.com/lima-vm/lima/pkg/store/filenames"
-	"github.com/lima-vm/lima/pkg/uiutil"
-	"github.com/lima-vm/lima/pkg/yqutil"
+	"github.com/lima-vm/lima/v2/cmd/limactl/editflags"
+	"github.com/lima-vm/lima/v2/pkg/autostart"
+	"github.com/lima-vm/lima/v2/pkg/driverutil"
+	"github.com/lima-vm/lima/v2/pkg/editutil"
+	"github.com/lima-vm/lima/v2/pkg/instance"
+	"github.com/lima-vm/lima/v2/pkg/limatype"
+	"github.com/lima-vm/lima/v2/pkg/limatype/dirnames"
+	"github.com/lima-vm/lima/v2/pkg/limatype/filenames"
+	"github.com/lima-vm/lima/v2/pkg/limayaml"
+	"github.com/lima-vm/lima/v2/pkg/networks/reconcile"
+	"github.com/lima-vm/lima/v2/pkg/store"
+	"github.com/lima-vm/lima/v2/pkg/uiutil"
+	"github.com/lima-vm/lima/v2/pkg/yqutil"
 )
 
 func newEditCommand() *cobra.Command {
@@ -33,11 +37,13 @@ func newEditCommand() *cobra.Command {
 		ValidArgsFunction: editBashComplete,
 		GroupID:           basicCommand,
 	}
+	editCommand.Flags().Bool("start", false, "Start the instance after editing")
 	editflags.RegisterEdit(editCommand, "")
 	return editCommand
 }
 
 func editAction(cmd *cobra.Command, args []string) error {
+	ctx := cmd.Context()
 	var arg string
 	if len(args) > 0 {
 		arg = args[0]
@@ -45,20 +51,20 @@ func editAction(cmd *cobra.Command, args []string) error {
 
 	var filePath string
 	var err error
-	var inst *store.Instance
+	var inst *limatype.Instance
 
 	if arg == "" {
 		arg = DefaultInstanceName
 	}
-	if err := store.ValidateInstName(arg); err == nil {
-		inst, err = store.Inspect(arg)
+	if err := dirnames.ValidateInstName(arg); err == nil {
+		inst, err = store.Inspect(ctx, arg)
 		if err != nil {
 			if errors.Is(err, os.ErrNotExist) {
 				return fmt.Errorf("instance %q not found", arg)
 			}
 			return err
 		}
-		if inst.Status == store.StatusRunning {
+		if inst.Status == limatype.StatusRunning {
 			return errors.New("cannot edit a running instance")
 		}
 		filePath = filepath.Join(inst.Dir, filenames.LimaYAML)
@@ -100,7 +106,7 @@ func editAction(cmd *cobra.Command, args []string) error {
 		hdr += "# and an empty file will abort the edit.\n"
 		hdr += "\n"
 		hdr += editutil.GenerateEditorWarningHeader()
-		yBytes, err = editutil.OpenEditor(yContent, hdr)
+		yBytes, err = editutil.OpenEditor(ctx, yContent, hdr)
 		if err != nil {
 			return err
 		}
@@ -113,15 +119,18 @@ func editAction(cmd *cobra.Command, args []string) error {
 		logrus.Info("Aborting, no changes made to the instance")
 		return nil
 	}
-	y, err := limayaml.LoadWithWarnings(yBytes, filePath)
+	y, err := limayaml.LoadWithWarnings(ctx, yBytes, filePath)
 	if err != nil {
 		return err
 	}
+	if err := driverutil.ResolveVMType(ctx, y, filePath); err != nil {
+		return fmt.Errorf("failed to resolve vm for %q: %w", filePath, err)
+	}
 	if err := limayaml.Validate(y, true); err != nil {
 		return saveRejectedYAML(yBytes, err)
 	}
 
-	if err := limayaml.ValidateAgainstLatestConfig(yBytes, yContent); err != nil {
+	if err := limayaml.ValidateAgainstLatestConfig(ctx, yBytes, yContent); err != nil {
 		return saveRejectedYAML(yBytes, err)
 	}
 
@@ -133,34 +142,42 @@ func editAction(cmd *cobra.Command, args []string) error {
 		logrus.Infof("Instance %q configuration edited", inst.Name)
 	}
 
-	if !tty {
-		// use "start" to start it
-		return nil
-	}
 	if inst == nil {
 		// edited a limayaml file directly
 		return nil
 	}
-	startNow, err := askWhetherToStart()
-	if err != nil {
-		return err
-	}
-	if !startNow {
-		return nil
-	}
-	ctx := cmd.Context()
-	err = networks.Reconcile(ctx, inst.Name)
+
+	start, err := flags.GetBool("start")
 	if err != nil {
 		return err
 	}
 
+	if tty && !flags.Changed("start") {
+		start, err = askWhetherToStart()
+		if err != nil {
+			return err
+		}
+	}
+	if !start {
+		return nil
+	}
+	// Network reconciliation will be performed by the process launched by the autostart manager
+	if registered, err := autostart.IsRegistered(ctx, inst); err != nil && !errors.Is(err, autostart.ErrNotSupported) {
+		return fmt.Errorf("failed to check if the autostart entry for instance %q is registered: %w", inst.Name, err)
+	} else if !registered {
+		err = reconcile.Reconcile(ctx, inst.Name)
+		if err != nil {
+			return err
+		}
+	}
+
 	// store.Inspect() syncs values between inst.YAML and the store.
 	// This call applies the validated template to the store.
-	inst, err = store.Inspect(inst.Name)
+	inst, err = store.Inspect(ctx, inst.Name)
 	if err != nil {
 		return err
 	}
-	return instance.Start(ctx, inst, "", false)
+	return instance.Start(ctx, inst, false, false)
 }
 
 func askWhetherToStart() (bool, error) {
