@@ -10,7 +10,7 @@ import (
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 
-	"github.com/lima-vm/lima/pkg/store"
+	"github.com/lima-vm/lima/v2/pkg/store"
 )
 
 func newProtectCommand() *cobra.Command {
@@ -27,10 +27,11 @@ The instance is not being protected against removal via '/bin/rm', Finder, etc.`
 	return protectCommand
 }
 
-func protectAction(_ *cobra.Command, args []string) error {
+func protectAction(cmd *cobra.Command, args []string) error {
+	ctx := cmd.Context()
 	var errs []error
 	for _, instName := range args {
-		inst, err := store.Inspect(instName)
+		inst, err := store.Inspect(ctx, instName)
 		if err != nil {
 			errs = append(errs, fmt.Errorf("failed to inspect instance %q: %w", instName, err))
 			continue
