@@ -13,10 +13,10 @@ import (
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 
-	"github.com/lima-vm/lima/pkg/sshutil"
-	"github.com/lima-vm/lima/pkg/store"
-	"github.com/lima-vm/lima/pkg/store/dirnames"
-	"github.com/lima-vm/lima/pkg/store/filenames"
+	"github.com/lima-vm/lima/v2/pkg/limatype/dirnames"
+	"github.com/lima-vm/lima/v2/pkg/limatype/filenames"
+	"github.com/lima-vm/lima/v2/pkg/sshutil"
+	"github.com/lima-vm/lima/v2/pkg/store"
 )
 
 const showSSHExample = `
@@ -77,13 +77,14 @@ Instead, use 'ssh -F %s/default/ssh.config lima-default' .
 }
 
 func showSSHAction(cmd *cobra.Command, args []string) error {
+	ctx := cmd.Context()
 	format, err := cmd.Flags().GetString("format")
 	if err != nil {
 		return err
 	}
 	instName := args[0]
 	w := cmd.OutOrStdout()
-	inst, err := store.Inspect(instName)
+	inst, err := store.Inspect(ctx, instName)
 	if err != nil {
 		if errors.Is(err, os.ErrNotExist) {
 			return fmt.Errorf("instance %q does not exist, run `limactl create %s` to create a new instance", instName, instName)
@@ -92,8 +93,13 @@ func showSSHAction(cmd *cobra.Command, args []string) error {
 	}
 	logrus.Warnf("`limactl show-ssh` is deprecated. Instead, use `ssh -F %s %s`.",
 		filepath.Join(inst.Dir, filenames.SSHConfig), inst.Hostname)
+	sshExe, err := sshutil.NewSSHExe()
+	if err != nil {
+		return err
+	}
 	opts, err := sshutil.SSHOpts(
-		"ssh",
+		ctx,
+		sshExe,
 		inst.Dir,
 		*inst.Config.User.Name,
 		*inst.Config.SSH.LoadDotSSHPubKeys,
