@@ -6,9 +6,9 @@ package main
 import (
 	"github.com/spf13/cobra"
 
-	"github.com/lima-vm/lima/pkg/instance"
-	networks "github.com/lima-vm/lima/pkg/networks/reconcile"
-	"github.com/lima-vm/lima/pkg/store"
+	"github.com/lima-vm/lima/v2/pkg/instance"
+	"github.com/lima-vm/lima/v2/pkg/networks/reconcile"
+	"github.com/lima-vm/lima/v2/pkg/store"
 )
 
 func newStopCommand() *cobra.Command {
@@ -26,12 +26,13 @@ func newStopCommand() *cobra.Command {
 }
 
 func stopAction(cmd *cobra.Command, args []string) error {
+	ctx := cmd.Context()
 	instName := DefaultInstanceName
 	if len(args) > 0 {
 		instName = args[0]
 	}
 
-	inst, err := store.Inspect(instName)
+	inst, err := store.Inspect(ctx, instName)
 	if err != nil {
 		return err
 	}
@@ -40,7 +41,6 @@ func stopAction(cmd *cobra.Command, args []string) error {
 	if err != nil {
 		return err
 	}
-	ctx := cmd.Context()
 	if force {
 		instance.StopForcibly(inst)
 	} else {
@@ -48,7 +48,7 @@ func stopAction(cmd *cobra.Command, args []string) error {
 	}
 	// TODO: should we also reconcile networks if graceful stop returned an error?
 	if err == nil {
-		err = networks.Reconcile(ctx, "")
+		err = reconcile.Reconcile(ctx, "")
 	}
 	return err
 }
