@@ -105,23 +105,20 @@ func startVM(ctx context.Context, inst *limatype.Instance, sshLocalPort int) (vm
 						defer close(notifySSHLocalPortAccessible)
 						usernetSSHLocalPort := sshLocalPort
 						useSSHOverVsock := true
-						if envVar := os.Getenv("LIMA_SSH_OVER_VSOCK"); envVar != "" {
-							b, err := strconv.ParseBool(envVar)
-							if err != nil {
-								logrus.WithError(err).Warnf("invalid LIMA_SSH_OVER_VSOCK value %q", envVar)
-							} else {
-								useSSHOverVsock = b
-							}
+						if inst.Config.SSH.OverVsock != nil {
+							useSSHOverVsock = *inst.Config.SSH.OverVsock
 						}
 						if !useSSHOverVsock {
-							logrus.Info("LIMA_SSH_OVER_VSOCK is false, skipping detection of SSH server on vsock port")
+							logrus.Info("ssh.overVsock is false, skipping detection of SSH server on vsock port")
 						} else if err := usernetClient.WaitOpeningSSHPort(ctx, inst); err == nil {
 							hostAddress := net.JoinHostPort(inst.SSHAddress, strconv.Itoa(usernetSSHLocalPort))
 							if err := wrapper.startVsockForwarder(ctx, 22, hostAddress); err == nil {
 								logrus.Infof("Detected SSH server is listening on the vsock port; changed %s to proxy for the vsock port", hostAddress)
 								usernetSSHLocalPort = 0 // disable gvisor ssh port forwarding
 							} else {
-								logrus.WithError(err).Warn("Failed to detect SSH server on vsock port, falling back to usernet forwarder")
+								logrus.WithError(err).WithField("hostAddress", hostAddress).
+									Debugf("Failed to start vsock forwarder (systemd is older than v256?)")
+								logrus.Info("SSH server does not seem to be running on vsock port, using usernet forwarder")
 							}
 						} else {
 							logrus.WithError(err).Warn("Failed to wait for the guest SSH server to become available, falling back to usernet forwarder")
