@@ -26,9 +26,8 @@ import (
 type Protocol string
 
 const (
-	// UDP/SCTP when lima port forwarding works on those protocols.
-
 	TCP Protocol = "tcp"
+	UDP Protocol = "udp"
 )
 
 type Entry struct {
@@ -58,11 +57,11 @@ func (s *ServiceWatcher) getServiceInformer() cache.SharedIndexInformer {
 	return s.serviceInformer
 }
 
-func (s *ServiceWatcher) Start() {
+func (s *ServiceWatcher) Start(ctx context.Context) {
 	logrus.Info("Monitoring kubernetes services")
 	const retryInterval = 10 * time.Second
 	const pollImmediately = false
-	_ = wait.PollUntilContextCancel(context.TODO(), retryInterval, pollImmediately, func(ctx context.Context) (done bool, err error) {
+	_ = wait.PollUntilContextCancel(ctx, retryInterval, pollImmediately, func(ctx context.Context) (done bool, err error) {
 		kubeClient, err := tryGetKubeClient()
 		if err != nil {
 			logrus.Tracef("failed to get kube client: %v, will retry in %v", err, retryInterval)
@@ -82,6 +81,7 @@ func (s *ServiceWatcher) Start() {
 func tryGetKubeClient() (kubernetes.Interface, error) {
 	candidateKubeConfigs := []string{
 		"/etc/rancher/k3s/k3s.yaml",
+		"/root/.kube/config.localhost", // Created by template:k8s
 		"/root/.kube/config",
 	}
 
@@ -134,8 +134,12 @@ func (s *ServiceWatcher) GetPorts() []Entry {
 		}
 
 		for _, portEntry := range service.Spec.Ports {
-			if portEntry.Protocol != corev1.ProtocolTCP {
-				// currently only TCP port can be forwarded
+			switch portEntry.Protocol {
+			case corev1.ProtocolTCP, corev1.ProtocolUDP:
+				// NOP
+			default:
+				logrus.Debugf("unsupported protocol %s for service %s/%s, skipping",
+					portEntry.Protocol, service.Namespace, service.Name)
 				continue
 			}
 
@@ -149,7 +153,7 @@ func (s *ServiceWatcher) GetPorts() []Entry {
 
 			entries = append(entries, Entry{
 				Protocol: Protocol(strings.ToLower(string(portEntry.Protocol))),
-				IP:       net.ParseIP("0.0.0.0"),
+				IP:       net.IPv4zero,
 				Port:     uint16(port),
 			})
 		}
