@@ -4,6 +4,7 @@
 package ioutilx
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"io"
@@ -49,8 +50,8 @@ func FromUTF16leToString(r io.Reader) (string, error) {
 	return string(out), nil
 }
 
-func WindowsSubsystemPath(orig string) (string, error) {
-	out, err := exec.Command("cygpath", filepath.ToSlash(orig)).CombinedOutput()
+func WindowsSubsystemPath(ctx context.Context, orig string) (string, error) {
+	out, err := exec.CommandContext(ctx, "cygpath", filepath.ToSlash(orig)).CombinedOutput()
 	if err != nil {
 		logrus.WithError(err).Errorf("failed to convert path to mingw, maybe not using Git ssh?")
 		return "", err
@@ -58,8 +59,8 @@ func WindowsSubsystemPath(orig string) (string, error) {
 	return strings.TrimSpace(string(out)), nil
 }
 
-func WindowsSubsystemPathForLinux(orig, distro string) (string, error) {
-	out, err := exec.Command("wsl", "-d", distro, "--exec", "wslpath", filepath.ToSlash(orig)).CombinedOutput()
+func WindowsSubsystemPathForLinux(ctx context.Context, orig, distro string) (string, error) {
+	out, err := exec.CommandContext(ctx, "wsl", "-d", distro, "--exec", "wslpath", filepath.ToSlash(orig)).CombinedOutput()
 	if err != nil {
 		logrus.WithError(err).Errorf("failed to convert path to mingw, maybe wsl command is not operational?")
 		return "", err
