@@ -4,7 +4,6 @@
 package limatmpl
 
 import (
-	"context"
 	"fmt"
 	"os"
 	"reflect"
@@ -15,7 +14,8 @@ import (
 	"gotest.tools/v3/assert"
 	"gotest.tools/v3/assert/cmp"
 
-	"github.com/lima-vm/lima/pkg/limayaml"
+	"github.com/lima-vm/lima/v2/pkg/limatype"
+	"github.com/lima-vm/lima/v2/pkg/limayaml"
 )
 
 type embedTestCase struct {
@@ -181,24 +181,24 @@ mounts:
 		`mounts: [{location: loc1}, {location: loc1, mountPoint: loc2, writable: true, sshfs: {followSymlinks: true}}, {location: loc1, mountPoint: loc3, writable: true}]`,
 	},
 	{
-		"template:// URLs are not embedded when embedAll is false",
+		"template: URLs are not embedded when embedAll is false",
 		// also tests file.url format
 		``,
 		`
-base: template://default
+base: template:default
 provision:
 - file:
-    url: template://provision.sh
+    url: template:provision.sh
 probes:
 - file:
-    url: template://probe.sh
+    url: template:probe.sh
 `,
 		`
-base: template://default
+base: template:default
 provision:
-- file: template://provision.sh
+- file: template:provision.sh
 probes:
-- file: template://probe.sh
+- file: template:probe.sh
 `,
 	},
 	{
@@ -214,18 +214,18 @@ vmType: qemu
 		`base template loop detected`,
 	},
 	{
-		"ERROR All bases following template:// bases must be template:// URLs too when embedAll is false",
+		"ERROR All bases following template: bases must be template: URLs too when embedAll is false",
 		``,
-		`base: [template://default, base1.yaml]`,
+		`base: [template:default, base1.yaml]`,
 		"after not embedding",
 	},
 	{
-		"ERROR All bases following template:// bases must be template:// URLs too when embedAll is false",
+		"ERROR All bases following template: bases must be template: URLs too when embedAll is false",
 		``,
 		`
 base: [base1.yaml, base2.yaml]
 ---
-base: template://default
+base: template:default
 ---
 base: baseX.yaml`,
 		"after not embedding",
@@ -343,6 +343,9 @@ provision:
 - mode: data
   file: base1.sh # This comment will move to the "content" key
   path: /tmp/data
+- mode: yq
+  file: base1.sh # This comment will move to the "expression" key
+  path: /tmp/yq
 `,
 		`
 # base0.yaml is ignored
@@ -364,6 +367,11 @@ provision:
     #!/usr/bin/env bash
     echo "This is base1.sh"
   path: /tmp/data
+- mode: yq
+  expression: |-  # This comment will move to the "expression" key
+    #!/usr/bin/env bash
+    echo "This is base1.sh"
+  path: /tmp/yq
 
 # base0.yaml is ignored
 `,
@@ -434,13 +442,7 @@ func RunEmbedTest(t *testing.T, tc embedTestCase) {
 	tc.expected = strings.TrimSpace(tc.expected)
 
 	// Change to temp directory so all template and script names don't include a slash.
-	cwd, err := os.Getwd()
-	assert.NilError(t, err, "Getting current working directory")
-	err = os.Chdir(t.TempDir())
-	assert.NilError(t, err, "Changing directory to t.TempDir()")
-	defer func() {
-		_ = os.Chdir(cwd)
-	}()
+	t.Chdir(t.TempDir())
 
 	for i, base := range strings.Split(tc.base, "---\n") {
 		extension := ".yaml"
@@ -459,7 +461,7 @@ func RunEmbedTest(t *testing.T, tc embedTestCase) {
 	if strings.HasPrefix(tc.base, "#!") {
 		tmpl.Bytes = []byte(tc.template)
 	}
-	err = tmpl.Embed(context.TODO(), false, false)
+	err := tmpl.Embed(t.Context(), false, false)
 	if expectError {
 		assert.ErrorContains(t, err, tc.expected, tc.description)
 		return
@@ -479,7 +481,7 @@ func RunEmbedTest(t *testing.T, tc embedTestCase) {
 	err = tmpl.Unmarshal()
 	assert.NilError(t, err, tc.description)
 
-	var expected limayaml.LimaYAML
+	var expected limatype.LimaYAML
 	err = limayaml.Unmarshal([]byte(tc.expected), &expected, "expected")
 	assert.NilError(t, err, tc.description)
 
@@ -501,6 +503,11 @@ func TestEncodeScriptReason(t *testing.T) {
 		reason := encodeScriptReason("abc\a123")
 		assert.Equal(t, reason, "unprintable character '\\a' at offset 3")
 	})
+	t.Run("contains a tab character", func(t *testing.T) {
+		// newline character is included in character count
+		reason := encodeScriptReason("foo\tbar")
+		assert.Equal(t, reason, "unprintable character '\\t' at offset 3")
+	})
 	t.Run("long line", func(t *testing.T) {
 		// newline character is included in character count
 		reason := encodeScriptReason("line 1\nline 2\n01234567\n")
