@@ -10,7 +10,7 @@ import (
 )
 
 func TestLoadEmpty(t *testing.T) {
-	_, err := Load([]byte{}, "empty.yaml")
+	_, err := Load(t.Context(), []byte{}, "empty.yaml")
 	assert.NilError(t, err)
 }
 
@@ -30,7 +30,7 @@ provision:
     #!/bin/sh
     echo three
 `
-	_, err := Load([]byte(s), "error.yaml")
+	_, err := Load(t.Context(), []byte(s), "error.yaml")
 	assert.ErrorContains(t, err, "map key-value is pre-defined")
 }
 
@@ -39,7 +39,7 @@ func TestLoadDiskString(t *testing.T) {
 additionalDisks:
 - name
 `
-	y, err := Load([]byte(s), "disk.yaml")
+	y, err := Load(t.Context(), []byte(s), "disk.yaml")
 	assert.NilError(t, err)
 	assert.Equal(t, len(y.AdditionalDisks), 1)
 	assert.Equal(t, y.AdditionalDisks[0].Name, "name")
@@ -56,7 +56,7 @@ additionalDisks:
   fsType: "xfs"
   fsArgs: ["-i","size=512"]
 `
-	y, err := Load([]byte(s), "disk.yaml")
+	y, err := Load(t.Context(), []byte(s), "disk.yaml")
 	assert.NilError(t, err)
 	assert.Assert(t, len(y.AdditionalDisks) == 1)
 	assert.Equal(t, y.AdditionalDisks[0].Name, "name")
