@@ -29,18 +29,15 @@ import (
 	"github.com/sirupsen/logrus"
 )
 
-// LockFile modified from https://github.com/boltdb/bolt/blob/v1.3.1/bolt_windows.go using MIT
+// LockFile modified from https://github.com/boltdb/bolt/blob/v1.3.1/bolt_windows.go using MIT.
 var (
 	modkernel32      = syscall.NewLazyDLL("kernel32.dll")
 	procLockFileEx   = modkernel32.NewProc("LockFileEx")
 	procUnlockFileEx = modkernel32.NewProc("UnlockFileEx")
 )
 
-const (
-	// see https://msdn.microsoft.com/en-us/library/windows/desktop/aa365203(v=vs.85).aspx
-	LOCKFILE_EXCLUSIVE_LOCK   = 0x00000002
-	LOCKFILE_FAIL_IMMEDIATELY = 0x00000001
-)
+// LOCKFILE_EXCLUSIVE_LOCK from https://msdn.microsoft.com/en-us/library/windows/desktop/aa365203(v=vs.85).aspx
+const flagLockfileExclusiveLock = 0x00000002
 
 func WithDirLock(dir string, fn func() error) error {
 	dirFile, err := os.OpenFile(dir+".lock", os.O_CREATE, 0o644)
@@ -50,7 +47,7 @@ func WithDirLock(dir string, fn func() error) error {
 	defer dirFile.Close()
 	if err := lockFileEx(
 		syscall.Handle(dirFile.Fd()), // hFile
-		LOCKFILE_EXCLUSIVE_LOCK,      // dwFlags
+		flagLockfileExclusiveLock,    // dwFlags
 		0,                            // dwReserved
 		1,                            // nNumberOfBytesToLockLow
 		0,                            // nNumberOfBytesToLockHigh
